comment *

    revision history

    CRC 12-11-00        updated comments, added equates


    This is a internal definitions file for using together with BUR version
    1.01

    Use this as a include file for your own code.

    assume that your code has:

    ZFINDEX     EQU 218H ; ZF-logic Index
    ZFRW1632    EQU 21AH


    Variables structure definition:

    This is the data structure, residing in MachZ on-chip SRAM when the BUR
    executes.  The starting address of this structure at segment 0 is defined
    at address F000:FF02 as word value


 -- vvvvvvv -- VER1.01 STRUCTURE FROM THAT POINT DOWN. DON'T CHANGE!


end comment *

CIRC_BUFF_SIZE  =       128
CMD_LINE_LEN    =       70
FZ_FIELD_LEN    =       11

;
; RED and GREEN switched 20.sep.2000 to match dongles already out.
; Only setback to this is, that BUR "Stop executing" command still lights up RED LED.
;

ZT_LED_RED      =       00000010b
ZT_LED_GREEN    =       00001000b

Variables       STRUC
                CircIn          dw      0
                CircOut         dw      0
                CircBuf         db      CIRC_BUFF_SIZE dup (0)
                Handshake       db      0       ; 1 if RTS/CTS is used
                SerialMode      db      0       ; 0=none 1=Serial 2=ZTAG_LEDS
                CRCFreez        db      0       ; if 1, ZTEXEC will freez on CRC errors
                CmdLine         db      CMD_LINE_LEN dup (0)
                Addressing      db      0       ; 0=real mode, 1=linear mode
                ColonInCmd      db      0
                LastDispCmd     dw      0       ; for d command: 0=ignore, entry to command otherwise
                LastEDX         dd      0       ; for d command
                UsrCmdStart     dw      0       ; start offset of user commands area (seg=70h)
                UsrCmdCount     dw      0       ; number of uploaded user-defined commands
                DownloadSegment dw      0       ; segment, where the downloadable code can start                                                ; (changed when user-defined command is loaded)
                YModemHdrByte   db      0       ; first byte of filename
                YModemFileSize  db      FZ_FIELD_LEN dup (0)
                YModemCRChi     db      0       ; received by YModem
                YModemCRClo     db      0
                YModemCRChi_C   db      0       ; UpdCRC routine uses these
                YModemCRClo_C   db      0
                YModemPktNo     db      0
                CountDown       dw      0
                QuickIRET       db      0       ; IRET placeholder
                RomSegment      dw      0       ; Code segment of ROM
                CachedOffset    dw      0       ; used for checking on code copy to cache

; -- ^^^^^^^ -- VER1.01 STRUCTURE FROM THAT POINT UP. DON'T CHANGE!

Variables       ENDS

;
; Data at the end of the BUR
;
;               org     0FF00h
;
;               dw      BUR_VERSION
;               dw      VAR_START
;               dw      offset  FarReturn
;

;
; Some helpers
;

DSBX2Var        proc
                push    0F000h
                pop     ds
                mov     bx, word ptr ds:[0FF02h]        ; get variables start
                push    0
                pop     ds                      ; DS:BX must point to variables area
                ret
DSBX2Var        endp

;
; These are calls to internal calls, supported by BUR code.
; The function names defined here are the same as used inside BUR
; source code.
;


;
; Display CR/LF to the active serial output console.
;
; Entry: none
;
; Exit: none
;
; Uses: flags
;

CRLF            proc
                db      9Ah             ;call imm.
                dd      0F000FF0Ah
                ret
CRLF            endp


;
; uncalibrated delay
;
; Entry: none
; Exit: none
; Uses: flags
;

Delay           proc
                db      9Ah             ;call imm.
                dd      0F000FF0Eh
                ret
Delay           endp


;
; Parse command line numeric parameter to EDX
;
; Entry: AL     - field type:   0 - byte:  0-0FFh
;                               1 - word:  0-0FFFFh
;                               2 - dword: 0-0FFFFFFFFh
;                               3 - address: (xxxx:xxxx if real addressing,
;                                             xxxxxxxx if linear addressing)
;        CL     - parameter number (1=first parameter)
;
; Exit:  EDX - parsed parameter value
;        CY - success
;        NC - invalid parameter or parameter missing
;
; Uses: flags
;

Parm2EDX        proc
                push    ds
                push    bx

                call    DSBX2Var
                db      9Ah             ;call imm.
                dd      0F000FF12h

                pop     bx
                pop     ds
                ret
Parm2EDX        endp

;
; ???
;

ResetCRC        proc
                db      9Ah             ;call imm.
                dd      0F000FF16h
                ret
ResetCRC        endp

;
; Seek SI to the specified command parameter number, so
; parameter start would be at 0:[Variables.CmsLine+SI]
;
; Entry: CL - parameter number
;
; Exit: SI - offset to parameter withing command line
;       CY - successful
;       NC - unsuccessful
;
; Uses: flags
;

SeekParm        proc
                push    ds
                push    bx

                call    DSBX2Var
                db      9Ah             ;call imm.
                dd      0F000FF1Ah

                pop     bx
                pop     ds
                ret
SeekParm        endp


;
; Display 8-bit value in AL to active serial console as number
;
; Entry: AL - value to display
;
; Exit: none
;
; Uses: flags
;

SerOut8         proc
                db      9Ah             ;call imm.
                dd      0F000FF1Eh
                ret
SerOut8         endp

;
; Display 16-bit value in AX to active serial console as number
;
; Entry: AX - value to display
;
; Exit: none
;
; Uses: flags
;

SerOut16        proc
                db      9Ah             ;call imm.
                dd      0F000FF22h
                ret
SerOut16        endp

;
; Display 32-bit value in EAX to active serial console as number
;
; Entry: EAX - value to display
;
; Exit: none
;
; Uses: flags
;

SerOut32        proc
                db      9Ah             ;call imm.
                dd      0F000FF26h
                ret
SerOut32        endp

;
; Display 8-bit value in AL to active serial console as bits
;
; Entry: AL - value to display
;
; Exit: none
;
; Uses: flags
;

SerOutBits      proc
                db      9Ah             ;call imm.
                dd      0F000FF2Ah
                ret
SerOutBits      endp

;
; Receive character from active serial console input with no waiting
;
; Entry: none
;
; Exit: AL - character received
;       ZF - if nothing was receiver
;       NZ - character is ready in AL
;
; Uses: flags
;

SerRec          proc
                db      9Ah             ;call imm.
                dd      0F000FF2Eh
                ret
SerRec          endp

;
; Wait 220ms for a character from active serial console input
;
; Entry: none
;
; Exit: AL - character received
;       ZF - if nothing was receiver
;       NZ - character is ready in AL
;
; Uses: flags
;

SerRecWait      proc
                db      9Ah             ;call imm.
                dd      0F000FF32h
                ret
SerRecWait      endp

;
; Send data byte to a active serial console output
;
; Entry: AL - byte to send
;
; Exit: none
;
; Uses: flags
;

SerSend2        proc
                db      9Ah             ;call imm.
                dd      0F000FF36h
                ret
SerSend2        endp

;
; Send string to a active serial console output
;
; Entry: ES:DI  - string to transmit
;        CX     - if string is not 0-terminated, this is the length to send
;                 Must be 0 if string is 0-terminated
;
; Exit: none
;
; Uses: flags
;

SerSend         proc
                db      9Ah             ;call imm.
                dd      0F000FF3Ah
                ret
SerSend         endp


;; Other defined commands

YModemGetData   proc
                db      9Ah             ;call imm.
                dd      0F000FF42h
                ret
YModemGetData   endp

YModemGetHeader proc
                db      9Ah             ;call imm.
                dd      0F000FF46h
                ret
YModemGetHeader endp

YModemSendData  proc
                db      9Ah             ;call imm.
                dd      0F000FF4Ah
                ret
YModemSendData  endp

YModemSendHeader proc
                db      9Ah             ;call imm.
                dd      0F000FF4Eh
                ret
YModemSendHeader endp

ZTCMDExec       proc
                db      9Ah             ;call imm.
                dd      0F000FF52h
                ret
ZTCMDExec       endp

ZT_Init         proc
                db      9Ah             ;call imm.
                dd      0F000FF56h
                ret
ZT_Init         endp

;
; Read byte through ZTAG.
;
; Note, that this function does not perform an accelerated read, so it is
; very slow and not that good to use
;
; Use ZTPrepareRead / ZTRead functions instead
;

ZT_Read         proc
                db      9Ah             ;call imm.
                dd      0F000FF5Ah
                ret
ZT_Read         endp

;
; Prepare ZFL registers for using ZTRead function
;

ZTPrepareRead   proc
                push    dx
                push    ax
                mov     dx, ZFINDEX
                mov     al, 80h
                out     dx, al
                pop     ax
                pop     dx
                ret
ZTPrepareRead   endp

;
; Read data byte through ZTAG accelerator, blinking with the LED
;
; Entry: none
;
; Exit: AL - byte read
;

ZTRead          proc
                push    dx
                push    ds
                push    bx
                push    ax

                call    DSBX2Var

                cmp     word ptr ds:[bx.CountDown], 0
                jnz     @f                      ; go check byte

                pushf
                cli
                mov     dx, ZFINDEX
                mov     al, 05Eh ;ZT_SIG_OUT
                out     dx, al
                inc     dx
                in      al, dx
                xor     al, (ZT_LED_RED + ZT_LED_GREEN)         ; flip both LEDs
                out     dx, al
                mov     word ptr ds:[bx.CountDown], 4   ; 4*55ms
                mov     dx, ZFINDEX                     ; restore register setup for read
                mov     al, 80h
                out     dx, al
                popf                                    ; restore interrupt status
@@:
                mov     dx, ZFRW1632
                in      ax, dx                          ; fetch data byte
                test    ah, 00000001b
                jz      @b

                ; byte is now in AL
                mov     dx, ax
                pop     ax
                pop     bx
                pop     ds
                mov     al, dl                          ; save data byte to AL
                pop     dx
                ret
ZTRead          endp
